/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.bolt.runtime.statemachine;

import org.neo4j.bolt.messaging.RequestMessage;
import org.neo4j.bolt.runtime.BoltConnectionFatality;
import org.neo4j.bolt.runtime.BoltResponseHandler;
import org.neo4j.bolt.runtime.Neo4jError;
import org.neo4j.exceptions.KernelException;

public interface BoltStateMachine extends AutoCloseable
{
    void process( RequestMessage message, BoltResponseHandler handler ) throws BoltConnectionFatality;

    boolean shouldStickOnThread();

    void validateTransaction() throws KernelException;

    boolean hasOpenStatement();

    void interrupt();

    boolean reset() throws BoltConnectionFatality;

    void markFailed( Neo4jError error );

    void handleFailure( Throwable cause, boolean fatal ) throws BoltConnectionFatality;

    void handleExternalFailure( Neo4jError error, BoltResponseHandler handler ) throws BoltConnectionFatality;

    void markForTermination();

    boolean isClosed();

    @Override
    void close();

    String id();
}
