/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.bolt.security.auth;

import java.io.IOException;

import org.neo4j.kernel.api.exceptions.Status;

public class AuthenticationException extends IOException implements Status.HasStatus
{
    private final Status status;

    public AuthenticationException( Status status )
    {
        this( status, status.code().description(), null );
    }

    public AuthenticationException( Status status, String message )
    {
        this( status, message, null );
    }

    public AuthenticationException( Status status, String message, Throwable e )
    {
        super( message, e );
        this.status = status;
    }

    @Override
    public Status status()
    {
        return status;
    }

}
