/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.api.impl.index.partition;

import org.apache.lucene.index.IndexWriterConfig;
import org.apache.lucene.store.Directory;

import java.io.IOException;
import java.nio.file.Path;
import java.util.function.Supplier;

/**
 * Factory to create writable partitions for partitioned index.
 */
public class WritableIndexPartitionFactory implements IndexPartitionFactory
{
    private final Supplier<IndexWriterConfig> writerConfigFactory;

    public WritableIndexPartitionFactory( Supplier<IndexWriterConfig> writerConfigFactory )
    {
        this.writerConfigFactory = writerConfigFactory;
    }

    @Override
    public AbstractIndexPartition createPartition( Path partitionFolder, Directory directory ) throws IOException
    {
        return new WritableIndexPartition( partitionFolder, directory, writerConfigFactory.get() );
    }
}
